Documentation
¶
Index ¶
Constants ¶
const (
PubsubComponentName = "sagatxs"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server interface {
CloseService()
SendStart(client dapr.Client, app_id string, service string, token string, callback_service string, params string, timeout int) error
SendStop(client dapr.Client, app_id string, service string, token string) error
// Note: The Methods below are not expcted to be used by consumers of the service and are used by the Poller & Subscriber
GetAllLogs(client dapr.Client, app_id string, service string)
DeleteStateEntry(key string) error
StoreStateEntry(key string, value []byte) error
}
func NewService ¶
@Summary Creates an instace of the Saga service. The DATABASE_URL environmnet variable must be set to the postgres URL. @ID NewService @Produce nil @Param topic The name of the topic to use to send to the corresponding Subscriber
type Start_stop ¶
type Start_stop = utility.Start_stop
Click to show internal directories.
Click to hide internal directories.